==> haskell-hpack-0.11.2-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hpack/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.11.2
id: hpack-0.11.2-43e56b25c412ed3db84879c1a99371a6
key: hpack_8cISFGy1on53hOlr7uG5dz
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
category: Development
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.GenericsUtil Hpack.Haskell Hpack.Render
                Hpack.Util Paths_hpack
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.11.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.11.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/hpack-0.11.2
hs-libraries: HShpack-0.11.2-8cISFGy1on53hOlr7uG5dz
depends:
    Glob-0.7.5-2de4d761061e270a9c358a45d1e533d4
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-compat-0.9.0-fa16321d7131a0167d57b06b47b516c7
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.12.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hpack/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.12.0
id: hpack-0.12.0-ee84233d84689f11811e47961d717695
key: hpack_KI7IaGCvrvDLwjwFpuPrQ9
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
category: Development
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Render Hpack.Util Paths_hpack
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.12.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.12.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/hpack-0.12.0
hs-libraries: HShpack-0.12.0-KI7IaGCvrvDLwjwFpuPrQ9
depends:
    Glob-0.7.5-2de4d761061e270a9c358a45d1e533d4
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-compat-0.9.0-fa16321d7131a0167d57b06b47b516c7
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    yaml-0.8.16-456c08a298c79f92e1296e690079eee9
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
